# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SourcePostgresArgs', 'SourcePostgres']

@pulumi.input_type
class SourcePostgresArgs:
    def __init__(__self__, *,
                 postgres_connection: pulumi.Input['SourcePostgresPostgresConnectionArgs'],
                 publication: pulumi.Input[str],
                 tables: pulumi.Input[Sequence[pulumi.Input['SourcePostgresTableArgs']]],
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 expose_progress: Optional[pulumi.Input['SourcePostgresExposeProgressArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SourcePostgres resource.
        :param pulumi.Input['SourcePostgresPostgresConnectionArgs'] postgres_connection: The PostgreSQL connection to use in the source.
        :param pulumi.Input[str] publication: The PostgreSQL publication (the replication data set containing the tables to be streamed to Materialize).
        :param pulumi.Input[Sequence[pulumi.Input['SourcePostgresTableArgs']]] tables: Creates subsources for specific tables in the Postgres connection.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input['SourcePostgresExposeProgressArgs'] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] text_columns: Decode data as text for specific columns that contain PostgreSQL types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        pulumi.set(__self__, "postgres_connection", postgres_connection)
        pulumi.set(__self__, "publication", publication)
        pulumi.set(__self__, "tables", tables)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if expose_progress is not None:
            pulumi.set(__self__, "expose_progress", expose_progress)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if text_columns is not None:
            pulumi.set(__self__, "text_columns", text_columns)

    @property
    @pulumi.getter(name="postgresConnection")
    def postgres_connection(self) -> pulumi.Input['SourcePostgresPostgresConnectionArgs']:
        """
        The PostgreSQL connection to use in the source.
        """
        return pulumi.get(self, "postgres_connection")

    @postgres_connection.setter
    def postgres_connection(self, value: pulumi.Input['SourcePostgresPostgresConnectionArgs']):
        pulumi.set(self, "postgres_connection", value)

    @property
    @pulumi.getter
    def publication(self) -> pulumi.Input[str]:
        """
        The PostgreSQL publication (the replication data set containing the tables to be streamed to Materialize).
        """
        return pulumi.get(self, "publication")

    @publication.setter
    def publication(self, value: pulumi.Input[str]):
        pulumi.set(self, "publication", value)

    @property
    @pulumi.getter
    def tables(self) -> pulumi.Input[Sequence[pulumi.Input['SourcePostgresTableArgs']]]:
        """
        Creates subsources for specific tables in the Postgres connection.
        """
        return pulumi.get(self, "tables")

    @tables.setter
    def tables(self, value: pulumi.Input[Sequence[pulumi.Input['SourcePostgresTableArgs']]]):
        pulumi.set(self, "tables", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> Optional[pulumi.Input['SourcePostgresExposeProgressArgs']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @expose_progress.setter
    def expose_progress(self, value: Optional[pulumi.Input['SourcePostgresExposeProgressArgs']]):
        pulumi.set(self, "expose_progress", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="textColumns")
    def text_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Decode data as text for specific columns that contain PostgreSQL types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "text_columns")

    @text_columns.setter
    def text_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "text_columns", value)


@pulumi.input_type
class _SourcePostgresState:
    def __init__(__self__, *,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 expose_progress: Optional[pulumi.Input['SourcePostgresExposeProgressArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 postgres_connection: Optional[pulumi.Input['SourcePostgresPostgresConnectionArgs']] = None,
                 publication: Optional[pulumi.Input[str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input['SourcePostgresTableArgs']]]] = None,
                 text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SourcePostgres resources.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input['SourcePostgresExposeProgressArgs'] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input['SourcePostgresPostgresConnectionArgs'] postgres_connection: The PostgreSQL connection to use in the source.
        :param pulumi.Input[str] publication: The PostgreSQL publication (the replication data set containing the tables to be streamed to Materialize).
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this source.
        :param pulumi.Input[Sequence[pulumi.Input['SourcePostgresTableArgs']]] tables: Creates subsources for specific tables in the Postgres connection.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] text_columns: Decode data as text for specific columns that contain PostgreSQL types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if expose_progress is not None:
            pulumi.set(__self__, "expose_progress", expose_progress)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if postgres_connection is not None:
            pulumi.set(__self__, "postgres_connection", postgres_connection)
        if publication is not None:
            pulumi.set(__self__, "publication", publication)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if tables is not None:
            pulumi.set(__self__, "tables", tables)
        if text_columns is not None:
            pulumi.set(__self__, "text_columns", text_columns)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> Optional[pulumi.Input['SourcePostgresExposeProgressArgs']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @expose_progress.setter
    def expose_progress(self, value: Optional[pulumi.Input['SourcePostgresExposeProgressArgs']]):
        pulumi.set(self, "expose_progress", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="postgresConnection")
    def postgres_connection(self) -> Optional[pulumi.Input['SourcePostgresPostgresConnectionArgs']]:
        """
        The PostgreSQL connection to use in the source.
        """
        return pulumi.get(self, "postgres_connection")

    @postgres_connection.setter
    def postgres_connection(self, value: Optional[pulumi.Input['SourcePostgresPostgresConnectionArgs']]):
        pulumi.set(self, "postgres_connection", value)

    @property
    @pulumi.getter
    def publication(self) -> Optional[pulumi.Input[str]]:
        """
        The PostgreSQL publication (the replication data set containing the tables to be streamed to Materialize).
        """
        return pulumi.get(self, "publication")

    @publication.setter
    def publication(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "publication", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[str]]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def tables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SourcePostgresTableArgs']]]]:
        """
        Creates subsources for specific tables in the Postgres connection.
        """
        return pulumi.get(self, "tables")

    @tables.setter
    def tables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SourcePostgresTableArgs']]]]):
        pulumi.set(self, "tables", value)

    @property
    @pulumi.getter(name="textColumns")
    def text_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Decode data as text for specific columns that contain PostgreSQL types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "text_columns")

    @text_columns.setter
    def text_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "text_columns", value)


class SourcePostgres(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 expose_progress: Optional[pulumi.Input[pulumi.InputType['SourcePostgresExposeProgressArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 postgres_connection: Optional[pulumi.Input[pulumi.InputType['SourcePostgresPostgresConnectionArgs']]] = None,
                 publication: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourcePostgresTableArgs']]]]] = None,
                 text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        A Postgres source describes a PostgreSQL instance you want Materialize to read data from.

        ## Import

        Sources can be imported using the source id

        ```sh
         $ pulumi import materialize:index/sourcePostgres:SourcePostgres example_source_postgres <region>:<source_id>
        ```

         Source id and information be found in the `mz_catalog.mz_sources` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[pulumi.InputType['SourcePostgresExposeProgressArgs']] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[pulumi.InputType['SourcePostgresPostgresConnectionArgs']] postgres_connection: The PostgreSQL connection to use in the source.
        :param pulumi.Input[str] publication: The PostgreSQL publication (the replication data set containing the tables to be streamed to Materialize).
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourcePostgresTableArgs']]]] tables: Creates subsources for specific tables in the Postgres connection.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] text_columns: Decode data as text for specific columns that contain PostgreSQL types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SourcePostgresArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A Postgres source describes a PostgreSQL instance you want Materialize to read data from.

        ## Import

        Sources can be imported using the source id

        ```sh
         $ pulumi import materialize:index/sourcePostgres:SourcePostgres example_source_postgres <region>:<source_id>
        ```

         Source id and information be found in the `mz_catalog.mz_sources` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param SourcePostgresArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SourcePostgresArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 expose_progress: Optional[pulumi.Input[pulumi.InputType['SourcePostgresExposeProgressArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 postgres_connection: Optional[pulumi.Input[pulumi.InputType['SourcePostgresPostgresConnectionArgs']]] = None,
                 publication: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourcePostgresTableArgs']]]]] = None,
                 text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SourcePostgresArgs.__new__(SourcePostgresArgs)

            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["expose_progress"] = expose_progress
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            if postgres_connection is None and not opts.urn:
                raise TypeError("Missing required property 'postgres_connection'")
            __props__.__dict__["postgres_connection"] = postgres_connection
            if publication is None and not opts.urn:
                raise TypeError("Missing required property 'publication'")
            __props__.__dict__["publication"] = publication
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            if tables is None and not opts.urn:
                raise TypeError("Missing required property 'tables'")
            __props__.__dict__["tables"] = tables
            __props__.__dict__["text_columns"] = text_columns
            __props__.__dict__["qualified_sql_name"] = None
            __props__.__dict__["size"] = None
        super(SourcePostgres, __self__).__init__(
            'materialize:index/sourcePostgres:SourcePostgres',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_name: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            expose_progress: Optional[pulumi.Input[pulumi.InputType['SourcePostgresExposeProgressArgs']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            postgres_connection: Optional[pulumi.Input[pulumi.InputType['SourcePostgresPostgresConnectionArgs']]] = None,
            publication: Optional[pulumi.Input[str]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            size: Optional[pulumi.Input[str]] = None,
            tables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourcePostgresTableArgs']]]]] = None,
            text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'SourcePostgres':
        """
        Get an existing SourcePostgres resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[pulumi.InputType['SourcePostgresExposeProgressArgs']] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[pulumi.InputType['SourcePostgresPostgresConnectionArgs']] postgres_connection: The PostgreSQL connection to use in the source.
        :param pulumi.Input[str] publication: The PostgreSQL publication (the replication data set containing the tables to be streamed to Materialize).
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this source.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourcePostgresTableArgs']]]] tables: Creates subsources for specific tables in the Postgres connection.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] text_columns: Decode data as text for specific columns that contain PostgreSQL types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SourcePostgresState.__new__(_SourcePostgresState)

        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["expose_progress"] = expose_progress
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["postgres_connection"] = postgres_connection
        __props__.__dict__["publication"] = publication
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["size"] = size
        __props__.__dict__["tables"] = tables
        __props__.__dict__["text_columns"] = text_columns
        return SourcePostgres(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[str]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> pulumi.Output[Optional['outputs.SourcePostgresExposeProgress']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter(name="postgresConnection")
    def postgres_connection(self) -> pulumi.Output['outputs.SourcePostgresPostgresConnection']:
        """
        The PostgreSQL connection to use in the source.
        """
        return pulumi.get(self, "postgres_connection")

    @property
    @pulumi.getter
    def publication(self) -> pulumi.Output[str]:
        """
        The PostgreSQL publication (the replication data set containing the tables to be streamed to Materialize).
        """
        return pulumi.get(self, "publication")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[str]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def tables(self) -> pulumi.Output[Sequence['outputs.SourcePostgresTable']]:
        """
        Creates subsources for specific tables in the Postgres connection.
        """
        return pulumi.get(self, "tables")

    @property
    @pulumi.getter(name="textColumns")
    def text_columns(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Decode data as text for specific columns that contain PostgreSQL types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "text_columns")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SourceLoadgenArgs', 'SourceLoadgen']

@pulumi.input_type
class SourceLoadgenArgs:
    def __init__(__self__, *,
                 load_generator_type: pulumi.Input[str],
                 auction_options: Optional[pulumi.Input['SourceLoadgenAuctionOptionsArgs']] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 counter_options: Optional[pulumi.Input['SourceLoadgenCounterOptionsArgs']] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 expose_progress: Optional[pulumi.Input['SourceLoadgenExposeProgressArgs']] = None,
                 key_value_options: Optional[pulumi.Input['SourceLoadgenKeyValueOptionsArgs']] = None,
                 marketing_options: Optional[pulumi.Input['SourceLoadgenMarketingOptionsArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 tpch_options: Optional[pulumi.Input['SourceLoadgenTpchOptionsArgs']] = None):
        """
        The set of arguments for constructing a SourceLoadgen resource.
        :param pulumi.Input[str] load_generator_type: The load generator types: [AUCTION MARKETING COUNTER TPCH KEY VALUE].
        :param pulumi.Input['SourceLoadgenAuctionOptionsArgs'] auction_options: Auction Options.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input['SourceLoadgenCounterOptionsArgs'] counter_options: Counter Options.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input['SourceLoadgenExposeProgressArgs'] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input['SourceLoadgenKeyValueOptionsArgs'] key_value_options: KEY VALUE Load Generator Options.
        :param pulumi.Input['SourceLoadgenMarketingOptionsArgs'] marketing_options: Marketing Options.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input['SourceLoadgenTpchOptionsArgs'] tpch_options: TPCH Options.
        """
        pulumi.set(__self__, "load_generator_type", load_generator_type)
        if auction_options is not None:
            pulumi.set(__self__, "auction_options", auction_options)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if counter_options is not None:
            pulumi.set(__self__, "counter_options", counter_options)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if expose_progress is not None:
            pulumi.set(__self__, "expose_progress", expose_progress)
        if key_value_options is not None:
            pulumi.set(__self__, "key_value_options", key_value_options)
        if marketing_options is not None:
            pulumi.set(__self__, "marketing_options", marketing_options)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if tpch_options is not None:
            pulumi.set(__self__, "tpch_options", tpch_options)

    @property
    @pulumi.getter(name="loadGeneratorType")
    def load_generator_type(self) -> pulumi.Input[str]:
        """
        The load generator types: [AUCTION MARKETING COUNTER TPCH KEY VALUE].
        """
        return pulumi.get(self, "load_generator_type")

    @load_generator_type.setter
    def load_generator_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "load_generator_type", value)

    @property
    @pulumi.getter(name="auctionOptions")
    def auction_options(self) -> Optional[pulumi.Input['SourceLoadgenAuctionOptionsArgs']]:
        """
        Auction Options.
        """
        return pulumi.get(self, "auction_options")

    @auction_options.setter
    def auction_options(self, value: Optional[pulumi.Input['SourceLoadgenAuctionOptionsArgs']]):
        pulumi.set(self, "auction_options", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="counterOptions")
    def counter_options(self) -> Optional[pulumi.Input['SourceLoadgenCounterOptionsArgs']]:
        """
        Counter Options.
        """
        return pulumi.get(self, "counter_options")

    @counter_options.setter
    def counter_options(self, value: Optional[pulumi.Input['SourceLoadgenCounterOptionsArgs']]):
        pulumi.set(self, "counter_options", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> Optional[pulumi.Input['SourceLoadgenExposeProgressArgs']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @expose_progress.setter
    def expose_progress(self, value: Optional[pulumi.Input['SourceLoadgenExposeProgressArgs']]):
        pulumi.set(self, "expose_progress", value)

    @property
    @pulumi.getter(name="keyValueOptions")
    def key_value_options(self) -> Optional[pulumi.Input['SourceLoadgenKeyValueOptionsArgs']]:
        """
        KEY VALUE Load Generator Options.
        """
        return pulumi.get(self, "key_value_options")

    @key_value_options.setter
    def key_value_options(self, value: Optional[pulumi.Input['SourceLoadgenKeyValueOptionsArgs']]):
        pulumi.set(self, "key_value_options", value)

    @property
    @pulumi.getter(name="marketingOptions")
    def marketing_options(self) -> Optional[pulumi.Input['SourceLoadgenMarketingOptionsArgs']]:
        """
        Marketing Options.
        """
        return pulumi.get(self, "marketing_options")

    @marketing_options.setter
    def marketing_options(self, value: Optional[pulumi.Input['SourceLoadgenMarketingOptionsArgs']]):
        pulumi.set(self, "marketing_options", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="tpchOptions")
    def tpch_options(self) -> Optional[pulumi.Input['SourceLoadgenTpchOptionsArgs']]:
        """
        TPCH Options.
        """
        return pulumi.get(self, "tpch_options")

    @tpch_options.setter
    def tpch_options(self, value: Optional[pulumi.Input['SourceLoadgenTpchOptionsArgs']]):
        pulumi.set(self, "tpch_options", value)


@pulumi.input_type
class _SourceLoadgenState:
    def __init__(__self__, *,
                 auction_options: Optional[pulumi.Input['SourceLoadgenAuctionOptionsArgs']] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 counter_options: Optional[pulumi.Input['SourceLoadgenCounterOptionsArgs']] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 expose_progress: Optional[pulumi.Input['SourceLoadgenExposeProgressArgs']] = None,
                 key_value_options: Optional[pulumi.Input['SourceLoadgenKeyValueOptionsArgs']] = None,
                 load_generator_type: Optional[pulumi.Input[str]] = None,
                 marketing_options: Optional[pulumi.Input['SourceLoadgenMarketingOptionsArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 tpch_options: Optional[pulumi.Input['SourceLoadgenTpchOptionsArgs']] = None):
        """
        Input properties used for looking up and filtering SourceLoadgen resources.
        :param pulumi.Input['SourceLoadgenAuctionOptionsArgs'] auction_options: Auction Options.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input['SourceLoadgenCounterOptionsArgs'] counter_options: Counter Options.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input['SourceLoadgenExposeProgressArgs'] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input['SourceLoadgenKeyValueOptionsArgs'] key_value_options: KEY VALUE Load Generator Options.
        :param pulumi.Input[str] load_generator_type: The load generator types: [AUCTION MARKETING COUNTER TPCH KEY VALUE].
        :param pulumi.Input['SourceLoadgenMarketingOptionsArgs'] marketing_options: Marketing Options.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this source.
        :param pulumi.Input['SourceLoadgenTpchOptionsArgs'] tpch_options: TPCH Options.
        """
        if auction_options is not None:
            pulumi.set(__self__, "auction_options", auction_options)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if counter_options is not None:
            pulumi.set(__self__, "counter_options", counter_options)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if expose_progress is not None:
            pulumi.set(__self__, "expose_progress", expose_progress)
        if key_value_options is not None:
            pulumi.set(__self__, "key_value_options", key_value_options)
        if load_generator_type is not None:
            pulumi.set(__self__, "load_generator_type", load_generator_type)
        if marketing_options is not None:
            pulumi.set(__self__, "marketing_options", marketing_options)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if tpch_options is not None:
            pulumi.set(__self__, "tpch_options", tpch_options)

    @property
    @pulumi.getter(name="auctionOptions")
    def auction_options(self) -> Optional[pulumi.Input['SourceLoadgenAuctionOptionsArgs']]:
        """
        Auction Options.
        """
        return pulumi.get(self, "auction_options")

    @auction_options.setter
    def auction_options(self, value: Optional[pulumi.Input['SourceLoadgenAuctionOptionsArgs']]):
        pulumi.set(self, "auction_options", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="counterOptions")
    def counter_options(self) -> Optional[pulumi.Input['SourceLoadgenCounterOptionsArgs']]:
        """
        Counter Options.
        """
        return pulumi.get(self, "counter_options")

    @counter_options.setter
    def counter_options(self, value: Optional[pulumi.Input['SourceLoadgenCounterOptionsArgs']]):
        pulumi.set(self, "counter_options", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> Optional[pulumi.Input['SourceLoadgenExposeProgressArgs']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @expose_progress.setter
    def expose_progress(self, value: Optional[pulumi.Input['SourceLoadgenExposeProgressArgs']]):
        pulumi.set(self, "expose_progress", value)

    @property
    @pulumi.getter(name="keyValueOptions")
    def key_value_options(self) -> Optional[pulumi.Input['SourceLoadgenKeyValueOptionsArgs']]:
        """
        KEY VALUE Load Generator Options.
        """
        return pulumi.get(self, "key_value_options")

    @key_value_options.setter
    def key_value_options(self, value: Optional[pulumi.Input['SourceLoadgenKeyValueOptionsArgs']]):
        pulumi.set(self, "key_value_options", value)

    @property
    @pulumi.getter(name="loadGeneratorType")
    def load_generator_type(self) -> Optional[pulumi.Input[str]]:
        """
        The load generator types: [AUCTION MARKETING COUNTER TPCH KEY VALUE].
        """
        return pulumi.get(self, "load_generator_type")

    @load_generator_type.setter
    def load_generator_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "load_generator_type", value)

    @property
    @pulumi.getter(name="marketingOptions")
    def marketing_options(self) -> Optional[pulumi.Input['SourceLoadgenMarketingOptionsArgs']]:
        """
        Marketing Options.
        """
        return pulumi.get(self, "marketing_options")

    @marketing_options.setter
    def marketing_options(self, value: Optional[pulumi.Input['SourceLoadgenMarketingOptionsArgs']]):
        pulumi.set(self, "marketing_options", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[str]]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="tpchOptions")
    def tpch_options(self) -> Optional[pulumi.Input['SourceLoadgenTpchOptionsArgs']]:
        """
        TPCH Options.
        """
        return pulumi.get(self, "tpch_options")

    @tpch_options.setter
    def tpch_options(self, value: Optional[pulumi.Input['SourceLoadgenTpchOptionsArgs']]):
        pulumi.set(self, "tpch_options", value)


class SourceLoadgen(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auction_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenAuctionOptionsArgs']]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 counter_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenCounterOptionsArgs']]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 expose_progress: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenExposeProgressArgs']]] = None,
                 key_value_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenKeyValueOptionsArgs']]] = None,
                 load_generator_type: Optional[pulumi.Input[str]] = None,
                 marketing_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenMarketingOptionsArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 tpch_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenTpchOptionsArgs']]] = None,
                 __props__=None):
        """
        A load generator source produces synthetic data for use in demos and performance tests.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_source_load_generator = materialize.SourceLoadgen("exampleSourceLoadGenerator",
            cluster_name="quickstart",
            counter_options=materialize.SourceLoadgenCounterOptionsArgs(
                tick_interval="500ms",
            ),
            load_generator_type="COUNTER",
            schema_name="schema")
        ```

        ## Import

        Sources can be imported using the source id

        ```sh
         $ pulumi import materialize:index/sourceLoadgen:SourceLoadgen example_source_load_generator <region>:<source_id>
        ```

         Source id and information be found in the `mz_catalog.mz_sources` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenAuctionOptionsArgs']] auction_options: Auction Options.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenCounterOptionsArgs']] counter_options: Counter Options.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenExposeProgressArgs']] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenKeyValueOptionsArgs']] key_value_options: KEY VALUE Load Generator Options.
        :param pulumi.Input[str] load_generator_type: The load generator types: [AUCTION MARKETING COUNTER TPCH KEY VALUE].
        :param pulumi.Input[pulumi.InputType['SourceLoadgenMarketingOptionsArgs']] marketing_options: Marketing Options.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenTpchOptionsArgs']] tpch_options: TPCH Options.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SourceLoadgenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A load generator source produces synthetic data for use in demos and performance tests.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_source_load_generator = materialize.SourceLoadgen("exampleSourceLoadGenerator",
            cluster_name="quickstart",
            counter_options=materialize.SourceLoadgenCounterOptionsArgs(
                tick_interval="500ms",
            ),
            load_generator_type="COUNTER",
            schema_name="schema")
        ```

        ## Import

        Sources can be imported using the source id

        ```sh
         $ pulumi import materialize:index/sourceLoadgen:SourceLoadgen example_source_load_generator <region>:<source_id>
        ```

         Source id and information be found in the `mz_catalog.mz_sources` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param SourceLoadgenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SourceLoadgenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auction_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenAuctionOptionsArgs']]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 counter_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenCounterOptionsArgs']]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 expose_progress: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenExposeProgressArgs']]] = None,
                 key_value_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenKeyValueOptionsArgs']]] = None,
                 load_generator_type: Optional[pulumi.Input[str]] = None,
                 marketing_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenMarketingOptionsArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 tpch_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenTpchOptionsArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SourceLoadgenArgs.__new__(SourceLoadgenArgs)

            __props__.__dict__["auction_options"] = auction_options
            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["counter_options"] = counter_options
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["expose_progress"] = expose_progress
            __props__.__dict__["key_value_options"] = key_value_options
            if load_generator_type is None and not opts.urn:
                raise TypeError("Missing required property 'load_generator_type'")
            __props__.__dict__["load_generator_type"] = load_generator_type
            __props__.__dict__["marketing_options"] = marketing_options
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["tpch_options"] = tpch_options
            __props__.__dict__["qualified_sql_name"] = None
            __props__.__dict__["size"] = None
        super(SourceLoadgen, __self__).__init__(
            'materialize:index/sourceLoadgen:SourceLoadgen',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auction_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenAuctionOptionsArgs']]] = None,
            cluster_name: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            counter_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenCounterOptionsArgs']]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            expose_progress: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenExposeProgressArgs']]] = None,
            key_value_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenKeyValueOptionsArgs']]] = None,
            load_generator_type: Optional[pulumi.Input[str]] = None,
            marketing_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenMarketingOptionsArgs']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            size: Optional[pulumi.Input[str]] = None,
            tpch_options: Optional[pulumi.Input[pulumi.InputType['SourceLoadgenTpchOptionsArgs']]] = None) -> 'SourceLoadgen':
        """
        Get an existing SourceLoadgen resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenAuctionOptionsArgs']] auction_options: Auction Options.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenCounterOptionsArgs']] counter_options: Counter Options.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenExposeProgressArgs']] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenKeyValueOptionsArgs']] key_value_options: KEY VALUE Load Generator Options.
        :param pulumi.Input[str] load_generator_type: The load generator types: [AUCTION MARKETING COUNTER TPCH KEY VALUE].
        :param pulumi.Input[pulumi.InputType['SourceLoadgenMarketingOptionsArgs']] marketing_options: Marketing Options.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this source.
        :param pulumi.Input[pulumi.InputType['SourceLoadgenTpchOptionsArgs']] tpch_options: TPCH Options.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SourceLoadgenState.__new__(_SourceLoadgenState)

        __props__.__dict__["auction_options"] = auction_options
        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["counter_options"] = counter_options
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["expose_progress"] = expose_progress
        __props__.__dict__["key_value_options"] = key_value_options
        __props__.__dict__["load_generator_type"] = load_generator_type
        __props__.__dict__["marketing_options"] = marketing_options
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["size"] = size
        __props__.__dict__["tpch_options"] = tpch_options
        return SourceLoadgen(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="auctionOptions")
    def auction_options(self) -> pulumi.Output[Optional['outputs.SourceLoadgenAuctionOptions']]:
        """
        Auction Options.
        """
        return pulumi.get(self, "auction_options")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[str]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="counterOptions")
    def counter_options(self) -> pulumi.Output[Optional['outputs.SourceLoadgenCounterOptions']]:
        """
        Counter Options.
        """
        return pulumi.get(self, "counter_options")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> pulumi.Output[Optional['outputs.SourceLoadgenExposeProgress']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @property
    @pulumi.getter(name="keyValueOptions")
    def key_value_options(self) -> pulumi.Output[Optional['outputs.SourceLoadgenKeyValueOptions']]:
        """
        KEY VALUE Load Generator Options.
        """
        return pulumi.get(self, "key_value_options")

    @property
    @pulumi.getter(name="loadGeneratorType")
    def load_generator_type(self) -> pulumi.Output[str]:
        """
        The load generator types: [AUCTION MARKETING COUNTER TPCH KEY VALUE].
        """
        return pulumi.get(self, "load_generator_type")

    @property
    @pulumi.getter(name="marketingOptions")
    def marketing_options(self) -> pulumi.Output[Optional['outputs.SourceLoadgenMarketingOptions']]:
        """
        Marketing Options.
        """
        return pulumi.get(self, "marketing_options")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[str]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="tpchOptions")
    def tpch_options(self) -> pulumi.Output[Optional['outputs.SourceLoadgenTpchOptions']]:
        """
        TPCH Options.
        """
        return pulumi.get(self, "tpch_options")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectionMysqlArgs', 'ConnectionMysql']

@pulumi.input_type
class ConnectionMysqlArgs:
    def __init__(__self__, *,
                 host: pulumi.Input[str],
                 user: pulumi.Input['ConnectionMysqlUserArgs'],
                 aws_privatelink: Optional[pulumi.Input['ConnectionMysqlAwsPrivatelinkArgs']] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input['ConnectionMysqlPasswordArgs']] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 ssh_tunnel: Optional[pulumi.Input['ConnectionMysqlSshTunnelArgs']] = None,
                 ssl_certificate: Optional[pulumi.Input['ConnectionMysqlSslCertificateArgs']] = None,
                 ssl_certificate_authority: Optional[pulumi.Input['ConnectionMysqlSslCertificateAuthorityArgs']] = None,
                 ssl_key: Optional[pulumi.Input['ConnectionMysqlSslKeyArgs']] = None,
                 ssl_mode: Optional[pulumi.Input[str]] = None,
                 validate: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a ConnectionMysql resource.
        :param pulumi.Input[str] host: The MySQL database hostname.
        :param pulumi.Input['ConnectionMysqlUserArgs'] user: The MySQL database username.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionMysqlAwsPrivatelinkArgs'] aws_privatelink: The AWS PrivateLink configuration for the MySQL database.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input['ConnectionMysqlPasswordArgs'] password: The MySQL database password.
        :param pulumi.Input[int] port: The MySQL database port.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema in Materialize. Defaults to `public`.
        :param pulumi.Input['ConnectionMysqlSshTunnelArgs'] ssh_tunnel: The SSH tunnel configuration for the MySQL database.
        :param pulumi.Input['ConnectionMysqlSslCertificateArgs'] ssl_certificate: The client certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionMysqlSslCertificateAuthorityArgs'] ssl_certificate_authority: The CA certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionMysqlSslKeyArgs'] ssl_key: The client key for the MySQL database.
        :param pulumi.Input[str] ssl_mode: The SSL mode for the MySQL database. Allowed values are disabled, required, verify-ca, verify-identity.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        pulumi.set(__self__, "host", host)
        pulumi.set(__self__, "user", user)
        if aws_privatelink is not None:
            pulumi.set(__self__, "aws_privatelink", aws_privatelink)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if ssh_tunnel is not None:
            pulumi.set(__self__, "ssh_tunnel", ssh_tunnel)
        if ssl_certificate is not None:
            pulumi.set(__self__, "ssl_certificate", ssl_certificate)
        if ssl_certificate_authority is not None:
            pulumi.set(__self__, "ssl_certificate_authority", ssl_certificate_authority)
        if ssl_key is not None:
            pulumi.set(__self__, "ssl_key", ssl_key)
        if ssl_mode is not None:
            pulumi.set(__self__, "ssl_mode", ssl_mode)
        if validate is not None:
            pulumi.set(__self__, "validate", validate)

    @property
    @pulumi.getter
    def host(self) -> pulumi.Input[str]:
        """
        The MySQL database hostname.
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: pulumi.Input[str]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter
    def user(self) -> pulumi.Input['ConnectionMysqlUserArgs']:
        """
        The MySQL database username.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "user")

    @user.setter
    def user(self, value: pulumi.Input['ConnectionMysqlUserArgs']):
        pulumi.set(self, "user", value)

    @property
    @pulumi.getter(name="awsPrivatelink")
    def aws_privatelink(self) -> Optional[pulumi.Input['ConnectionMysqlAwsPrivatelinkArgs']]:
        """
        The AWS PrivateLink configuration for the MySQL database.
        """
        return pulumi.get(self, "aws_privatelink")

    @aws_privatelink.setter
    def aws_privatelink(self, value: Optional[pulumi.Input['ConnectionMysqlAwsPrivatelinkArgs']]):
        pulumi.set(self, "aws_privatelink", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input['ConnectionMysqlPasswordArgs']]:
        """
        The MySQL database password.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input['ConnectionMysqlPasswordArgs']]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        The MySQL database port.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="sshTunnel")
    def ssh_tunnel(self) -> Optional[pulumi.Input['ConnectionMysqlSshTunnelArgs']]:
        """
        The SSH tunnel configuration for the MySQL database.
        """
        return pulumi.get(self, "ssh_tunnel")

    @ssh_tunnel.setter
    def ssh_tunnel(self, value: Optional[pulumi.Input['ConnectionMysqlSshTunnelArgs']]):
        pulumi.set(self, "ssh_tunnel", value)

    @property
    @pulumi.getter(name="sslCertificate")
    def ssl_certificate(self) -> Optional[pulumi.Input['ConnectionMysqlSslCertificateArgs']]:
        """
        The client certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate")

    @ssl_certificate.setter
    def ssl_certificate(self, value: Optional[pulumi.Input['ConnectionMysqlSslCertificateArgs']]):
        pulumi.set(self, "ssl_certificate", value)

    @property
    @pulumi.getter(name="sslCertificateAuthority")
    def ssl_certificate_authority(self) -> Optional[pulumi.Input['ConnectionMysqlSslCertificateAuthorityArgs']]:
        """
        The CA certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate_authority")

    @ssl_certificate_authority.setter
    def ssl_certificate_authority(self, value: Optional[pulumi.Input['ConnectionMysqlSslCertificateAuthorityArgs']]):
        pulumi.set(self, "ssl_certificate_authority", value)

    @property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> Optional[pulumi.Input['ConnectionMysqlSslKeyArgs']]:
        """
        The client key for the MySQL database.
        """
        return pulumi.get(self, "ssl_key")

    @ssl_key.setter
    def ssl_key(self, value: Optional[pulumi.Input['ConnectionMysqlSslKeyArgs']]):
        pulumi.set(self, "ssl_key", value)

    @property
    @pulumi.getter(name="sslMode")
    def ssl_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The SSL mode for the MySQL database. Allowed values are disabled, required, verify-ca, verify-identity.
        """
        return pulumi.get(self, "ssl_mode")

    @ssl_mode.setter
    def ssl_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ssl_mode", value)

    @property
    @pulumi.getter
    def validate(self) -> Optional[pulumi.Input[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")

    @validate.setter
    def validate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "validate", value)


@pulumi.input_type
class _ConnectionMysqlState:
    def __init__(__self__, *,
                 aws_privatelink: Optional[pulumi.Input['ConnectionMysqlAwsPrivatelinkArgs']] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 host: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input['ConnectionMysqlPasswordArgs']] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 ssh_tunnel: Optional[pulumi.Input['ConnectionMysqlSshTunnelArgs']] = None,
                 ssl_certificate: Optional[pulumi.Input['ConnectionMysqlSslCertificateArgs']] = None,
                 ssl_certificate_authority: Optional[pulumi.Input['ConnectionMysqlSslCertificateAuthorityArgs']] = None,
                 ssl_key: Optional[pulumi.Input['ConnectionMysqlSslKeyArgs']] = None,
                 ssl_mode: Optional[pulumi.Input[str]] = None,
                 user: Optional[pulumi.Input['ConnectionMysqlUserArgs']] = None,
                 validate: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering ConnectionMysql resources.
        :param pulumi.Input['ConnectionMysqlAwsPrivatelinkArgs'] aws_privatelink: The AWS PrivateLink configuration for the MySQL database.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] host: The MySQL database hostname.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input['ConnectionMysqlPasswordArgs'] password: The MySQL database password.
        :param pulumi.Input[int] port: The MySQL database port.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the connection.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema in Materialize. Defaults to `public`.
        :param pulumi.Input['ConnectionMysqlSshTunnelArgs'] ssh_tunnel: The SSH tunnel configuration for the MySQL database.
        :param pulumi.Input['ConnectionMysqlSslCertificateArgs'] ssl_certificate: The client certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionMysqlSslCertificateAuthorityArgs'] ssl_certificate_authority: The CA certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input['ConnectionMysqlSslKeyArgs'] ssl_key: The client key for the MySQL database.
        :param pulumi.Input[str] ssl_mode: The SSL mode for the MySQL database. Allowed values are disabled, required, verify-ca, verify-identity.
        :param pulumi.Input['ConnectionMysqlUserArgs'] user: The MySQL database username.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        if aws_privatelink is not None:
            pulumi.set(__self__, "aws_privatelink", aws_privatelink)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if ssh_tunnel is not None:
            pulumi.set(__self__, "ssh_tunnel", ssh_tunnel)
        if ssl_certificate is not None:
            pulumi.set(__self__, "ssl_certificate", ssl_certificate)
        if ssl_certificate_authority is not None:
            pulumi.set(__self__, "ssl_certificate_authority", ssl_certificate_authority)
        if ssl_key is not None:
            pulumi.set(__self__, "ssl_key", ssl_key)
        if ssl_mode is not None:
            pulumi.set(__self__, "ssl_mode", ssl_mode)
        if user is not None:
            pulumi.set(__self__, "user", user)
        if validate is not None:
            pulumi.set(__self__, "validate", validate)

    @property
    @pulumi.getter(name="awsPrivatelink")
    def aws_privatelink(self) -> Optional[pulumi.Input['ConnectionMysqlAwsPrivatelinkArgs']]:
        """
        The AWS PrivateLink configuration for the MySQL database.
        """
        return pulumi.get(self, "aws_privatelink")

    @aws_privatelink.setter
    def aws_privatelink(self, value: Optional[pulumi.Input['ConnectionMysqlAwsPrivatelinkArgs']]):
        pulumi.set(self, "aws_privatelink", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[str]]:
        """
        The MySQL database hostname.
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input['ConnectionMysqlPasswordArgs']]:
        """
        The MySQL database password.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input['ConnectionMysqlPasswordArgs']]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        The MySQL database port.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the connection.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the connection schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="sshTunnel")
    def ssh_tunnel(self) -> Optional[pulumi.Input['ConnectionMysqlSshTunnelArgs']]:
        """
        The SSH tunnel configuration for the MySQL database.
        """
        return pulumi.get(self, "ssh_tunnel")

    @ssh_tunnel.setter
    def ssh_tunnel(self, value: Optional[pulumi.Input['ConnectionMysqlSshTunnelArgs']]):
        pulumi.set(self, "ssh_tunnel", value)

    @property
    @pulumi.getter(name="sslCertificate")
    def ssl_certificate(self) -> Optional[pulumi.Input['ConnectionMysqlSslCertificateArgs']]:
        """
        The client certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate")

    @ssl_certificate.setter
    def ssl_certificate(self, value: Optional[pulumi.Input['ConnectionMysqlSslCertificateArgs']]):
        pulumi.set(self, "ssl_certificate", value)

    @property
    @pulumi.getter(name="sslCertificateAuthority")
    def ssl_certificate_authority(self) -> Optional[pulumi.Input['ConnectionMysqlSslCertificateAuthorityArgs']]:
        """
        The CA certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate_authority")

    @ssl_certificate_authority.setter
    def ssl_certificate_authority(self, value: Optional[pulumi.Input['ConnectionMysqlSslCertificateAuthorityArgs']]):
        pulumi.set(self, "ssl_certificate_authority", value)

    @property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> Optional[pulumi.Input['ConnectionMysqlSslKeyArgs']]:
        """
        The client key for the MySQL database.
        """
        return pulumi.get(self, "ssl_key")

    @ssl_key.setter
    def ssl_key(self, value: Optional[pulumi.Input['ConnectionMysqlSslKeyArgs']]):
        pulumi.set(self, "ssl_key", value)

    @property
    @pulumi.getter(name="sslMode")
    def ssl_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The SSL mode for the MySQL database. Allowed values are disabled, required, verify-ca, verify-identity.
        """
        return pulumi.get(self, "ssl_mode")

    @ssl_mode.setter
    def ssl_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ssl_mode", value)

    @property
    @pulumi.getter
    def user(self) -> Optional[pulumi.Input['ConnectionMysqlUserArgs']]:
        """
        The MySQL database username.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "user")

    @user.setter
    def user(self, value: Optional[pulumi.Input['ConnectionMysqlUserArgs']]):
        pulumi.set(self, "user", value)

    @property
    @pulumi.getter
    def validate(self) -> Optional[pulumi.Input[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")

    @validate.setter
    def validate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "validate", value)


class ConnectionMysql(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_privatelink: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlAwsPrivatelinkArgs']]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 host: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlPasswordArgs']]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 ssh_tunnel: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSshTunnelArgs']]] = None,
                 ssl_certificate: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateArgs']]] = None,
                 ssl_certificate_authority: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateAuthorityArgs']]] = None,
                 ssl_key: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslKeyArgs']]] = None,
                 ssl_mode: Optional[pulumi.Input[str]] = None,
                 user: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlUserArgs']]] = None,
                 validate: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        A MySQL connection establishes a link to a single database of a MySQL server.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a MySQL Connection with SSH tunnel & plain text user
        example_mysql_connection = materialize.ConnectionMysql("exampleMysqlConnection",
            host="instance.foo000.us-west-1.rds.amazonaws.com",
            password=materialize.ConnectionMysqlPasswordArgs(
                database_name="database",
                name="example",
                schema_name="schema",
            ),
            port=3306,
            ssh_tunnel=materialize.ConnectionMysqlSshTunnelArgs(
                name="example",
            ),
            user=materialize.ConnectionMysqlUserArgs(
                text="my_user",
            ))
        ```

        ## Import

        Connections can be imported using the connection id

        ```sh
         $ pulumi import materialize:index/connectionMysql:ConnectionMysql example <region>:<connection_id>
        ```

         Connection id and information be found in the `mz_catalog.mz_connections` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlAwsPrivatelinkArgs']] aws_privatelink: The AWS PrivateLink configuration for the MySQL database.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] host: The MySQL database hostname.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlPasswordArgs']] password: The MySQL database password.
        :param pulumi.Input[int] port: The MySQL database port.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema in Materialize. Defaults to `public`.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlSshTunnelArgs']] ssh_tunnel: The SSH tunnel configuration for the MySQL database.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateArgs']] ssl_certificate: The client certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateAuthorityArgs']] ssl_certificate_authority: The CA certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlSslKeyArgs']] ssl_key: The client key for the MySQL database.
        :param pulumi.Input[str] ssl_mode: The SSL mode for the MySQL database. Allowed values are disabled, required, verify-ca, verify-identity.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlUserArgs']] user: The MySQL database username.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectionMysqlArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A MySQL connection establishes a link to a single database of a MySQL server.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a MySQL Connection with SSH tunnel & plain text user
        example_mysql_connection = materialize.ConnectionMysql("exampleMysqlConnection",
            host="instance.foo000.us-west-1.rds.amazonaws.com",
            password=materialize.ConnectionMysqlPasswordArgs(
                database_name="database",
                name="example",
                schema_name="schema",
            ),
            port=3306,
            ssh_tunnel=materialize.ConnectionMysqlSshTunnelArgs(
                name="example",
            ),
            user=materialize.ConnectionMysqlUserArgs(
                text="my_user",
            ))
        ```

        ## Import

        Connections can be imported using the connection id

        ```sh
         $ pulumi import materialize:index/connectionMysql:ConnectionMysql example <region>:<connection_id>
        ```

         Connection id and information be found in the `mz_catalog.mz_connections` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param ConnectionMysqlArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionMysqlArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_privatelink: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlAwsPrivatelinkArgs']]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 host: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlPasswordArgs']]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 ssh_tunnel: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSshTunnelArgs']]] = None,
                 ssl_certificate: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateArgs']]] = None,
                 ssl_certificate_authority: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateAuthorityArgs']]] = None,
                 ssl_key: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslKeyArgs']]] = None,
                 ssl_mode: Optional[pulumi.Input[str]] = None,
                 user: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlUserArgs']]] = None,
                 validate: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionMysqlArgs.__new__(ConnectionMysqlArgs)

            __props__.__dict__["aws_privatelink"] = aws_privatelink
            __props__.__dict__["comment"] = comment
            __props__.__dict__["database_name"] = database_name
            if host is None and not opts.urn:
                raise TypeError("Missing required property 'host'")
            __props__.__dict__["host"] = host
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["password"] = password
            __props__.__dict__["port"] = port
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["ssh_tunnel"] = ssh_tunnel
            __props__.__dict__["ssl_certificate"] = ssl_certificate
            __props__.__dict__["ssl_certificate_authority"] = ssl_certificate_authority
            __props__.__dict__["ssl_key"] = ssl_key
            __props__.__dict__["ssl_mode"] = ssl_mode
            if user is None and not opts.urn:
                raise TypeError("Missing required property 'user'")
            __props__.__dict__["user"] = user
            __props__.__dict__["validate"] = validate
            __props__.__dict__["qualified_sql_name"] = None
        super(ConnectionMysql, __self__).__init__(
            'materialize:index/connectionMysql:ConnectionMysql',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aws_privatelink: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlAwsPrivatelinkArgs']]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            host: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlPasswordArgs']]] = None,
            port: Optional[pulumi.Input[int]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            ssh_tunnel: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSshTunnelArgs']]] = None,
            ssl_certificate: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateArgs']]] = None,
            ssl_certificate_authority: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateAuthorityArgs']]] = None,
            ssl_key: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlSslKeyArgs']]] = None,
            ssl_mode: Optional[pulumi.Input[str]] = None,
            user: Optional[pulumi.Input[pulumi.InputType['ConnectionMysqlUserArgs']]] = None,
            validate: Optional[pulumi.Input[bool]] = None) -> 'ConnectionMysql':
        """
        Get an existing ConnectionMysql resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlAwsPrivatelinkArgs']] aws_privatelink: The AWS PrivateLink configuration for the MySQL database.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[str] host: The MySQL database hostname.
        :param pulumi.Input[str] name: The identifier for the connection.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlPasswordArgs']] password: The MySQL database password.
        :param pulumi.Input[int] port: The MySQL database port.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the connection.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the connection schema in Materialize. Defaults to `public`.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlSshTunnelArgs']] ssh_tunnel: The SSH tunnel configuration for the MySQL database.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateArgs']] ssl_certificate: The client certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlSslCertificateAuthorityArgs']] ssl_certificate_authority: The CA certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlSslKeyArgs']] ssl_key: The client key for the MySQL database.
        :param pulumi.Input[str] ssl_mode: The SSL mode for the MySQL database. Allowed values are disabled, required, verify-ca, verify-identity.
        :param pulumi.Input[pulumi.InputType['ConnectionMysqlUserArgs']] user: The MySQL database username.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        :param pulumi.Input[bool] validate: **Private Preview** If the connection should wait for validation.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionMysqlState.__new__(_ConnectionMysqlState)

        __props__.__dict__["aws_privatelink"] = aws_privatelink
        __props__.__dict__["comment"] = comment
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["host"] = host
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["password"] = password
        __props__.__dict__["port"] = port
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["ssh_tunnel"] = ssh_tunnel
        __props__.__dict__["ssl_certificate"] = ssl_certificate
        __props__.__dict__["ssl_certificate_authority"] = ssl_certificate_authority
        __props__.__dict__["ssl_key"] = ssl_key
        __props__.__dict__["ssl_mode"] = ssl_mode
        __props__.__dict__["user"] = user
        __props__.__dict__["validate"] = validate
        return ConnectionMysql(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="awsPrivatelink")
    def aws_privatelink(self) -> pulumi.Output[Optional['outputs.ConnectionMysqlAwsPrivatelink']]:
        """
        The AWS PrivateLink configuration for the MySQL database.
        """
        return pulumi.get(self, "aws_privatelink")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the connection database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def host(self) -> pulumi.Output[str]:
        """
        The MySQL database hostname.
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the connection.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional['outputs.ConnectionMysqlPassword']]:
        """
        The MySQL database password.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[int]]:
        """
        The MySQL database port.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the connection.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the connection schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter(name="sshTunnel")
    def ssh_tunnel(self) -> pulumi.Output[Optional['outputs.ConnectionMysqlSshTunnel']]:
        """
        The SSH tunnel configuration for the MySQL database.
        """
        return pulumi.get(self, "ssh_tunnel")

    @property
    @pulumi.getter(name="sslCertificate")
    def ssl_certificate(self) -> pulumi.Output[Optional['outputs.ConnectionMysqlSslCertificate']]:
        """
        The client certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate")

    @property
    @pulumi.getter(name="sslCertificateAuthority")
    def ssl_certificate_authority(self) -> pulumi.Output[Optional['outputs.ConnectionMysqlSslCertificateAuthority']]:
        """
        The CA certificate for the MySQL database.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "ssl_certificate_authority")

    @property
    @pulumi.getter(name="sslKey")
    def ssl_key(self) -> pulumi.Output[Optional['outputs.ConnectionMysqlSslKey']]:
        """
        The client key for the MySQL database.
        """
        return pulumi.get(self, "ssl_key")

    @property
    @pulumi.getter(name="sslMode")
    def ssl_mode(self) -> pulumi.Output[Optional[str]]:
        """
        The SSL mode for the MySQL database. Allowed values are disabled, required, verify-ca, verify-identity.
        """
        return pulumi.get(self, "ssl_mode")

    @property
    @pulumi.getter
    def user(self) -> pulumi.Output['outputs.ConnectionMysqlUser']:
        """
        The MySQL database username.. Can be supplied as either free text using `text` or reference to a secret object using `secret`.
        """
        return pulumi.get(self, "user")

    @property
    @pulumi.getter
    def validate(self) -> pulumi.Output[Optional[bool]]:
        """
        **Private Preview** If the connection should wait for validation.
        """
        return pulumi.get(self, "validate")

